@@ -59,7 +59,7 @@ int mib[2];
 	len = sizeof(ret);
 	sysctl(mib,2,&ret,&len,NULL,0);
 	getrlimit(RLIMIT_DATA,&rr);
-	if ( ret > (unsigned int)rr.rlim_max )
+	if ( rr.rlim_max && ret > (unsigned int)rr.rlim_max )
 		ret = rr.rlim_max;
 	mem_size = ret;
 	return ret;
