@@ -20,8 +20,8 @@
 #ifndef ___M_THREAD_2_END_H___
 #define ___M_THREAD_2_END_H___
 
-
-#define SCHED_POLICY	SCHED_RR
+#define SCHED_SUPER_POLICY	SCHED_OTHER
+#define SCHED_POLICY		SCHED_OTHER
 
 
 typedef struct sw_hash {
