@@ -73,7 +73,7 @@ int pfd1[2], pfd2[2];
 		return -1;
 
 	errno = 0;
-	p[0] = d_alloc(sizeof(S_FPIPE),134);
+	p[0] = d_alloc(sizeof(S_FPIPE));
 	p[0]->h.tbl = &s_fpipe_table;
 	p[0]->h.thread = 0;
 	p[0]->fpipe.fid_read = pfd1[0];
@@ -83,7 +83,7 @@ int pfd1[2], pfd2[2];
 	p[0]->fpipe.flags = 0;
 	p[0]->fpipe.this_ip_addr = p[0]->fpipe.peer_ip_addr = 0;
 
-	p[1] = d_alloc(sizeof(S_FPIPE),134);
+	p[1] = d_alloc(sizeof(S_FPIPE));
 	p[1]->h.tbl = &s_fpipe_table;
 	p[1]->h.thread = 0;
 	p[1]->fpipe.fid_read = pfd2[0];
@@ -267,7 +267,7 @@ int ip;
 		wakeup_task((int)s);
 		return 1;
 	}
-	b = d_alloc(sizeof(*b)+len,123);
+	b = d_alloc(sizeof(*b)+len);
 	ptr = (char*)(b+1);
 	b->ptr = 0;
 	b->len = len;
@@ -403,7 +403,7 @@ int mode;
 
 	pr->ptr ++;
 
-	ret = d_alloc(sizeof(S_FPIPE),133);
+	ret = d_alloc(sizeof(S_FPIPE));
 	ret->h.tbl = pr->tbl;
 	ret->h.thread = 0;
 	ret->fpipe.head = ret->fpipe.tail = 0;
