@@ -181,7 +181,7 @@ new_lock(int level)
 {
 SEM s;
 SEM *sp;
-	s = d_alloc(sizeof(*s),307);
+	s = d_alloc(sizeof(*s));
 	sem_init(s,0,1);
 	s->level = level;
 	s->tid = 0;
@@ -254,7 +254,7 @@ new_lock(int level)
 {
 SEM s;
 
-	s = d_alloc(sizeof(*s),307);
+	s = d_alloc(sizeof(*s));
 	sem_init(s,0,1);
 	sem_trywait(s);
 	sem_post(s);
@@ -356,7 +356,7 @@ create_task(void (*func)(),int data, int pri)
 unsigned long ret;
 TASK_BLOCK *tb;
 	
-	tb = (TASK_BLOCK *)d_alloc(sizeof(*tb), 309);
+	tb = (TASK_BLOCK *)d_alloc(sizeof(*tb));
 	
 	tb->func = (void (__cdecl *)(void *))func;
 	tb->data = data;
@@ -377,6 +377,7 @@ TASK_BLOCK *tb;
 	else{
 		change_pri(ret, pri);
 	}
+	return ret;
 }
 
 void
@@ -496,4 +497,4 @@ int i;
 			test_tno[i] = no;
 			return;
 		}
-}
\ No newline at end of file
+}
