@@ -32,7 +32,7 @@ int fd;
 	if ( path == 0 )
 		return 0;
 	path = copy_str(path);
-	buf = d_alloc(strlen(path) + strlen(app) + 10,2);
+	buf = d_alloc(strlen(path) + strlen(app) + 10);
 	buf[0] = 0;
 	for ( p1 = path ; p1 ; ) {
 		p2 = p1;
