@@ -81,16 +81,16 @@ set_note(
 {
 NOTE * n;
 
-	n = d_alloc(sizeof(*n),1234);
+	n = d_alloc(sizeof(*n));
 	n->type = type;
 	if ( img )
-		n->img = ll_copy_str(img,123);
+		n->img = ll_copy_str(img);
 	else	n->img = 0;
 	n->fill_color = fill_color;
 	n->line_color = line_color;
-	n->data = ll_copy_str(data,123);
+	n->data = ll_copy_str(data);
 	if ( url )
-		n->url = ll_copy_str(url,123);
+		n->url = ll_copy_str(url);
 	else	n->url = 0;
 
 	n->next = r->h.notes;
@@ -400,9 +400,9 @@ L_CHAR * qq;
 L_CHAR * dt;
 BIB_LIST ** blp;
 
-	bl = d_alloc(sizeof(*bl),123);
+	bl = d_alloc(sizeof(*bl));
 	bl->inherit = inh;
-	bl->namespace = ll_copy_str(ns,1581);
+	bl->namespace = ll_copy_str(ns);
 	for ( qq = q ; ; qq ++ ) {
 		switch ( *qq ) {
 		case 0:
@@ -416,15 +416,15 @@ BIB_LIST ** blp;
 		}
 		break;
 	}
-	bl->qualifier = ll_copy_str(qq,1581);
+	bl->qualifier = ll_copy_str(qq);
 	dt = get_sf_attribute(sf,l_string(std_cm,"type"));
 	if ( dt == 0 )
 		bl->type = nl_copy_str(std_cm,"text");
-	else	bl->type = ll_copy_str(dt,1581);
+	else	bl->type = ll_copy_str(dt);
 	dt = get_sf_attribute(sf,l_string(std_cm,"data"));
 	if ( dt == 0 )
 		bl->data = nl_copy_str(std_cm,"");
-	else	bl->data = ll_copy_str(dt,1581);
+	else	bl->data = ll_copy_str(dt);
 	r->h.bib = insert_bib_list(r->h.bib,bl);
 }
 
@@ -464,12 +464,12 @@ BIB_LIST * bl2;
 	ret = 0;
 	blp = &ret;
 	for ( ; bl ; ) {
-		bl2 = d_alloc(sizeof(*bl),11);
-		bl2->namespace = ll_copy_str(bl->namespace,1582);
+		bl2 = d_alloc(sizeof(*bl));
+		bl2->namespace = ll_copy_str(bl->namespace);
 		bl2->inherit = bl->inherit;
-		bl2->qualifier = ll_copy_str(bl->qualifier,1582);
-		bl2->type = ll_copy_str(bl->type,1582);
-		bl2->data = ll_copy_str(bl->data,1582);
+		bl2->qualifier = ll_copy_str(bl->qualifier);
+		bl2->type = ll_copy_str(bl->type);
+		bl2->data = ll_copy_str(bl->data);
 		bl2->next = 0;
 		*blp = bl2;
 		blp = &(*blp)->next;
@@ -529,7 +529,7 @@ get_ns(XL_SYM_FIELD * ns_sf,L_CHAR * sym)
 L_CHAR * dt;
 L_CHAR * qq;
 
-	dt = ll_copy_str(sym,1583);
+	dt = ll_copy_str(sym);
 	for ( qq = dt ; ; qq ++ ) {
 		switch ( *qq ) {
 		case 0:
@@ -676,14 +676,15 @@ int minrect_flag;
 UNIT_ENV * uenv;
 L_CHAR * f;
 XL_SEXP * _mod;
+XL_SEXP * ret;
 
 	setup_c_unit(
-		&r->h.cu,-1,f=ll_copy_str(get_url_str2(&r->h.entry),123),
+		&r->h.cu,-1,f=ll_copy_str(get_url_str2(&r->h.entry)),
 		meta,0);
 	d_f_ree(f);
 
 	minrect_flag = 0;
-	for ( s = meta ; get_type(s) ; s = cdr(s) ) {
+	for ( s = meta ; get_type(s) == XLT_PAIR ; s = cdr(s) ) {
 		if ( get_type(s) != XLT_PAIR )
 			break;
 		rec = car(s);
@@ -788,7 +789,7 @@ int data_state;
 		e_param = "4th";
 		goto type_missmatch;
 	}
-	get_url2(&u_entry,entry->string.data,1606);
+	get_url2(&u_entry,entry->string.data);
 	if ( get_url_str2(&u_entry) == 0 ) {
 		e_param = "entry URL(2nd)";
 		goto param_error;
@@ -804,7 +805,7 @@ int data_state;
 			data_state = NR_KEEP;
 		free_url(&u_entry);
 	}
-	get_url2(&u,target->string.data,1607);
+	get_url2(&u,target->string.data);
 	if ( get_url_str2(&u) == 0 ) {
 		e_param = "target URL (3rd)";
 		goto param_error;
@@ -1124,7 +1125,7 @@ URL u;
 		e_param = "1st";
 		goto type_missmatch;
 	}
-	get_url2(&u,uu->string.data,1608);
+	get_url2(&u,uu->string.data);
 	switch ( type ) {
 	case 0:
 		r = search_resource_by_entry(&u);
