@@ -30,7 +30,7 @@ L_CHAR * f;
 URL u;
 void gc_gb_sexp();
 
-	get_url2(&u,target,1609);
+	get_url2(&u,target);
 
 	gc_push(0,0,"remote_fetch");
 	gt = get_symbol(l_string(std_cm,"Get"));
