@@ -65,6 +65,27 @@ XLISP_ENV * map_top,* map_cmd;
 }
 
 
+static int test_map_reso_task;
+
+void
+test_map_reso(char* str,REAL1 * reso,int size,int data)
+{
+int i;
+
+	if ( str == 0 ) {
+		if ( data ) 
+			test_map_reso_task = get_tid();
+		else	test_map_reso_task = 0;
+		return;
+	}
+	if ( test_map_reso_task != get_tid() )
+		return;
+	ss_printf("RESO %s(%i:%x) ",str,data,data);
+	for ( i = 0 ; i < size ; i ++ )
+		ss_printf("%f ",reso[i]);
+	ss_printf("\n");
+}
+
 void
 free_clip(CLIP * c)
 {
@@ -466,9 +487,13 @@ map_conv_reverse_pp(MAP_HISTORY * mh,GB_POINT * p,REAL1 * reso,int size)
 int i;
 GB_POINT pp;
 GB_POINT3D pp3d;
-double d,rrate;
-
+double d,rrate,lambda_rate;
+GB_POINT * _p;
+REAL1 * _reso;
+	_p = p;
+	_reso = reso;
 	rrate = 1/mh->d.pp.forward_rate;
+	lambda_rate = mh->d.pp.lambda*mh->d.pp.forward_rate;
 	for ( i = 0 ; i < size ; i ++ , p ++ , reso ++ ) {
 		if ( *reso < 0 )
 			continue;
@@ -519,10 +544,22 @@ double d,rrate;
 		}
 		else	pp.x = 0;
 		pp.y = asin(-pp3d.y);
+/*
 		pp.x = pp.x * rrate + mh->d.pp.lambda;
 		pp.y = pp.y * rrate;
+*/
+		pp.x = pp.x + lambda_rate;
 		*p = pp;
 	}
+	adjust_lambda(l_string(std_cm,"rad"),_p->x - M_PI,_p,_reso,0,size);
+	for ( i = 0 ; i < size ; i ++ , _p ++ , _reso ++ ) {
+		if ( *_reso < 0 )
+			continue;
+		pp = *_p;
+		pp.x = pp.x * rrate;
+		pp.y = pp.y * rrate;
+		*_p = pp;
+	}
 }
 
 void
@@ -614,6 +651,7 @@ GB_POINT mv;
 void
 map_from_flame(MAP_HISTORY * mh,GB_POINT * ptr,REAL1 * reso,int size)
 {
+
 	for ( ; mh ; mh = mh->next ) {
 		switch ( mh->type ) {
 		case MHT_MAP:
@@ -840,8 +878,9 @@ MAP_HISTORY*
 new_mh(RESOURCE * m,short dir)
 {
 MAP_HISTORY * ret;
+
 if ( m == 0 )
-printf("***** new_mh\n");
+er_panic("new_mh");
 	ret = d_alloc(sizeof(*ret));
 	ret->dir = dir;
 	ret->type = MHT_MAP;
@@ -861,14 +900,78 @@ MAP_HISTORY * ret;
 }
 
 
+GROUP_SET *
+new_gs(REAL1 * reso,GROUP_ID * g,int size)
+{
+GROUP_SET * ret;
+GROUP_ID id;
+	ret = d_alloc(sizeof(*ret));
+	memset(ret,0,sizeof(*ret));
+	id = 0;
+	for ( ; size ; g ++ , reso ++ ,size -- ) {
+		if ( *reso < 0 )
+			continue;
+		if ( *g >= id )
+			id = (*g) + 1;
+	}
+	ret->next_id = id;
+	return ret;
+}
+
+GROUP_ID
+new_group(GROUP_SET * gs,GROUP_ID prev,int x_cnt,int y_cnt)
+{
+GROUP_SET_LIST ** gslp, * gsl;
+GROUP_ID ret;
+	for ( gslp = &gs->list ; *gslp ; gslp = &(*gslp)->next ) {
+		gsl = *gslp;
+		if ( gsl->x_cnt == x_cnt &&
+				gsl->y_cnt == y_cnt &&
+				gsl->prev_gid == prev ) {
+			*gslp = gsl->next;
+			gsl->next = gs->list;
+			gs->list = gsl;
+			return gsl->gid;
+		}
+	}
+	ret = gs->next_id ++;
+	gsl = d_alloc(sizeof(*gsl));
+	gsl->x_cnt = x_cnt;
+	gsl->y_cnt = y_cnt;
+	gsl->prev_gid = prev;
+	gsl->gid = ret;
+	gsl->next = gs->list;
+	gs->list = gsl;
+	return ret;
+}
+
+void
+free_gs(GROUP_SET * gs)
+{
+GROUP_SET_LIST * gsl;
+	for ( ; gs->list ; ) {
+		gsl = gs->list;
+		gs->list = gsl->next;
+		d_f_ree(gsl);
+	}
+	d_f_ree(gs);
+}
+
+
+
 void
 adjust_lambda(L_CHAR * unit,REAL1 min_point,
-	GB_POINT * pt_list,REAL1 * reso,int size)
+	GB_POINT * pt_list,REAL1 * reso,GROUP_ID * group,int size)
 {
 REAL1 loop,max_point,x,y;
 REAL1 vertical1,vertical2,vertical3;
 int i;
 int sign;
+GROUP_SET * gs;
+int y_cnt,x_cnt;
+	if ( group )
+		gs = new_gs(reso,group,size);
+	else 	gs = 0;
 
 	if ( l_strcmp(unit,l_string(std_cm,"rad")) == 0 )
 		loop = 2*M_PI;
@@ -883,13 +986,15 @@ int sign;
 	vertical2 = loop/2;
 	vertical3 = loop*3/4;
 	max_point = min_point + loop;
-	for ( i = 0; i< size ; i ++ , pt_list ++ , reso ++ ) {
+	for ( i = 0; i< size ; i ++ , pt_list ++ , reso ++ 
+			, group ? group ++ : 0 ) {
 		if ( *reso < 0 )
 			continue;
 		x = pt_list->x;
 		y = pt_list->y;
 		if ( y > 0 ) {
-			for ( ; y > loop ; y -= loop );
+			y_cnt = 0;
+			for ( ; y > loop ; y -= loop , y_cnt ++ );
 			if ( y <= vertical1 ) {
 			}
 			else if ( y <= vertical3 ) {
@@ -901,7 +1006,8 @@ int sign;
 			}
 		}
 		else {
-			for ( ; y < -loop ; y += loop );
+			y_cnt = 0;
+			for ( ; y < -loop ; y += loop , y_cnt -- );
 			if ( y >= -vertical1 ) {
 			}
 			else if ( y >= -vertical3 ) {
@@ -912,11 +1018,16 @@ int sign;
 				y = loop + y;
 			}
 		}
-		for ( ; x < min_point ; x += loop );
-		for ( ; x > max_point ; x -= loop );
+		x_cnt = 0;
+		for ( ; x < min_point ; x += loop , x_cnt -- );
+		for ( ; x > max_point ; x -= loop , x_cnt ++ );
 		pt_list->x = x;
 		pt_list->y = y;
+		if ( group )
+			*group = new_group(gs,*group,x_cnt,y_cnt);
 	}
+	if ( gs )
+		free_gs(gs);
 }
 
 
@@ -952,8 +1063,10 @@ int i,j;
 		}
 	}
 
-	for ( i = 0 ; i < SURP_NOS ; i ++ )
+	for ( i = 0 ; i < SURP_NOS ; i ++ ) {
 		surp->reso[i] = reso;
+		surp->group[i] = 0;
+	}
 }
 
 void
@@ -974,12 +1087,47 @@ int i;
 }
 
 
-GB_RECT
-get_surp_rect(SURP_SET * surp,RESOURCE * r)
+GROUP_ID
+surp_group_optimize(SURP_SET * surp)
 {
-GB_RECT ret;
+int len;
+GROUP_ID * list;
+GROUP_ID n,g;
+GROUP_SET * gs;
 int i;
+	list = 0;
+	len = 0;
+	n = 1;
+	for ( i = 0 ; i < SURP_NOS ; i ++ ) {
+		if ( surp->reso[i] < 0 )
+			continue;
+		g = surp->group[i];
+		if ( g < len ) {
+			if ( list[g] )
+				continue;
+			list[g] = n ++;
+			continue;
+		}
+		len = g + 1;
+		list = d_re_alloc(list,len*sizeof(GROUP_ID));
+		list[g] = n ++;
+	}
+	for ( i = 0 ; i < SURP_NOS ; i ++ ) {
+		if ( surp->reso[i] < 0 )
+			continue;
+		surp->group[i] = list[surp->group[i]] - 1;
+	}
+	if ( list )
+		d_f_ree(list);
+	return n-1;
+}
 
+GB_RECT *
+get_surp_rect(int *rect_nos,SURP_SET * surp,RESOURCE * r)
+{
+int i;
+GB_RECT * ret;
+GROUP_ID n;
 
 	if ( r )
 		adjust_lambda(
@@ -987,33 +1135,48 @@ int i;
 			r->h.minrect.tl.x,
 			surp->ptr,
 			surp->reso,
+			surp->group,
 			SURP_NOS);
+	n = surp_group_optimize(surp);
+	ret = d_alloc(sizeof(*ret)*n);
 
-	ret.tl.x = ret.tl.y = 0;
-	ret.br.x = ret.br.y = -1;
+	for ( i = 0 ; i < n ; i ++ ) {
+		ret[i].tl.x = ret[i].tl.y = 0;
+		ret[i].br.x = ret[i].br.y = -1;
+	}
 	for ( i = 0 ; i < SURP_NOS ; i ++ ) {
 		if ( surp->reso[i] < 0 )
 			continue;
-		insert_rect(&ret,surp->ptr[i]);
+		insert_rect(&ret[surp->group[i]],surp->ptr[i]);
+	}
+	*rect_nos = n;
+	if ( n == 0 ) {
+		d_f_ree(ret);
+		return 0;
 	}
 	return ret;
 }
 
-GB_RECT
-get_surp_rect_rate(SURP_SET * surp,REAL1 rate,RESOURCE * r)
+GB_RECT *
+get_surp_rect_rate(int * ret_len,SURP_SET * surp,REAL1 rate,RESOURCE * r)
 {
-GB_RECT ret;
+GB_RECT * ret, * rp;
 REAL1 w,h;
 REAL1 x_ofs,y_ofs;
-	ret = get_surp_rect(surp,r);
-	w = ret.br.x - ret.tl.x;
-	h = ret.br.y - ret.tl.y;
-	x_ofs = w*rate;
-	y_ofs = h*rate;
-	ret.br.x += x_ofs;
-	ret.br.y += y_ofs;
-	ret.tl.x -= x_ofs;
-	ret.tl.y -= y_ofs;
+int i,n;
+	ret = get_surp_rect(&n,surp,r);
+	for ( i = 0 ; i < n ; i ++ ) {
+		rp = &ret[i];
+		w = rp->br.x - rp->tl.x;
+		h = rp->br.y - rp->tl.y;
+		x_ofs = w*rate;
+		y_ofs = h*rate;
+		rp->br.x += x_ofs;
+		rp->br.y += y_ofs;
+		rp->tl.x -= x_ofs;
+		rp->tl.y -= y_ofs;
+	}
+	*ret_len = n;
 	return ret;
 }
 
