@@ -441,6 +441,8 @@ L_CHAR * f, * g;
 	}
 	if ( r ) {
 		r->h.flags |= RF_COMPLETE;
+		if ( err < 0 )
+			r->h.flags |= RF_ERROR;
 		wakeup_task((int)r);
 		rcache_invoke();
 	}
@@ -1852,7 +1854,7 @@ printf("RESORCE CACHE INVOKE\n");
 	for ( i = 0 ; i < RES_HASH_SIZE ; ) {
 		lock_task(res_lock);
 		for ( r = res_no_hash_table[i] ; r ; r = r->h.no_next )
-			if ( (r->h.flags & (RF_CACHE|RF_COMPLETE|RF_LOAD_EXTEND_PROC|RF_UNCACHE))
+			if ( (r->h.flags & (RF_CACHE|RF_COMPLETE|RF_LOAD_EXTEND_PROC|RF_UNCACHE|RF_ERROR))
 					== RF_COMPLETE ) {
 				break;
 			}
