@@ -29,6 +29,13 @@
 #include	"save_global.h"
 
 
+void
+target_org_check(MP_ROUTE * mpr,L_CHAR * target,L_CHAR * org);
+void
+target_org_check_path(MP_PATH * path,L_CHAR * target,L_CHAR * org);
+void
+ss_print_path(char * str,MP_PATH * path);
+
 #define MIN_CACHE_EXPIRE	60
 #define MAX_CACHE_EXPIRE	(30*24*3600)
 typedef struct rrr_type {
@@ -819,6 +826,7 @@ ok:
 	for ( p = target_ptr ; p && p != p_tar ; p = p->next ) {
 		pp = copy_mp_path(p);
 		pp->next = p_tar_result;
+		p_tar_result = pp;
 	}
 	if ( p == 0 ) {
 		free_mp_path(p_tar_result);
@@ -1647,6 +1655,197 @@ MP_PATH * c;
 	printf("mpr end\n");
 }
 
+void
+ss_print_mpr(MP_ROUTE * mpr)
+{
+MP_PATH * c;
+	printf("mpr\n");
+	for ( c = mpr->head ; c ; c = c->next )
+		ss_printf("  %ls\n",c->url);
+	printf("mpr end\n");
+}
+
+void
+ss_print_path(char * str,MP_PATH * path)
+{
+MP_PATH * p;
+	ss_printf("PATH %s\n",str);
+	for ( p = path ; p ; p = p->next )
+		ss_printf("  %ls\n",p->url);
+	ss_printf("PATH END\n");
+}
+
+void
+target_org_check_path(MP_PATH * path,L_CHAR * target,L_CHAR * org)
+{
+MP_PATH * p;
+	if ( path == 0 )
+		return;
+	for ( p = path ; p->next ; p = p->next );
+	if ( l_strcmp(path->url,target) == 0 &&
+		l_strcmp(p->url,org) == 0 ||
+		l_strcmp(path->url,org) == 0 &&
+		l_strcmp(p->url,target) == 0 )
+		return;
+	ss_printf("TARGET ORG PATH %ls %ls\n",
+		target,org);
+	for ( p = path ; p ; p = p->next )
+		ss_printf("  %ls\n",p->url);
+	er_panic("target_org_check PATH");
+}
+
+void
+target_org_check(MP_ROUTE * mpr,L_CHAR * target,L_CHAR * org)
+{
+	if ( mpr == 0 || mpr == MP_NO_ROUTE )
+		return;
+	if ( l_strcmp(mpr->head->url,target) == 0 &&
+		l_strcmp(mpr->tail->url,org) == 0 ||
+		l_strcmp(mpr->head->url,org) == 0 &&
+		l_strcmp(mpr->tail->url,target) == 0 )
+		return;
+	ss_printf("TARGET ORG %ls %ls\n",
+		target,org);
+	ss_print_mpr(mpr);
+	er_panic("target_org_check");
+}
+
+void
+_check_mappath_mh(L_CHAR * org,L_CHAR * target,MAP_HISTORY * mh,MP_ROUTE * mpr)
+{
+char * p_str;
+MAP_HISTORY * mh1;
+URL u;
+URL * before, * n,* _n;
+	if ( mh == MP_MH_NO_ROUTE )
+		return;
+	for ( mh1 = mh ; mh1 ; mh1 = mh1->next )
+		if ( mh1->type != MHT_MAP )
+			return;
+	if ( mh == 0 )
+		return;
+	if ( org ) {
+		get_url2(&u,org);
+		if ( mh->dir == MHD_FORWARD ) {
+			if ( url_cmp(&mh->d.map->map.src,&u) == 0 )
+				goto ok_org_src;
+		}
+		else {
+			if ( url_cmp(&mh->d.map->map.dest,&u) == 0 )
+				goto ok_org_src;
+		}
+		for ( mh1 = mh ; mh1->next ; mh1 = mh1->next );
+		if ( mh1->dir == MHD_FORWARD ) {
+			if ( url_cmp(&mh1->d.map->map.dest,&u) == 0 )
+				goto ok_org_dest;
+		}
+		else {
+			if ( url_cmp(&mh1->d.map->map.src,&u) == 0 )
+				goto ok_org_dest;
+		}
+	}
+	goto ok_org_both;
+ok_org_src:
+	free_url(&u);
+	for ( mh1 = mh ; mh1->next ; mh1 = mh1->next );
+	get_url2(&u,target);
+	if ( mh1->dir == MHD_FORWARD ) {
+		if ( url_cmp(&mh1->d.map->map.dest,&u) == 0 )
+			goto ok;
+	}
+	else {
+		if ( url_cmp(&mh1->d.map->map.src,&u) == 0 )
+			goto ok;
+	}
+	p_str = "check_mappath_mh(1)";
+	goto panic;
+ok_org_dest:
+	free_url(&u);
+	get_url2(&u,target);
+	if ( mh->dir == MHD_FORWARD ) {
+		if ( url_cmp(&mh->d.map->map.src,&u) == 0 )
+			goto ok;
+	}
+	else {
+		if ( url_cmp(&mh->d.map->map.dest,&u) == 0 )
+			goto ok;
+	}
+	p_str = "check_mappath_mh(2)";
+	goto panic;
+ok_org_both:
+	free_url(&u);
+	get_url2(&u,target);
+	if ( mh->dir == MHD_FORWARD ) {
+		if ( url_cmp(&mh->d.map->map.src,&u) == 0 )
+			goto ok;
+	}
+	else {
+		if ( url_cmp(&mh->d.map->map.dest,&u) == 0 )
+			goto ok;
+	}
+	for ( mh1 = mh ; mh1->next ; mh1 = mh1->next );
+	get_url2(&u,target);
+	if ( mh1->dir == MHD_FORWARD ) {
+		if ( url_cmp(&mh1->d.map->map.dest,&u) == 0 )
+			goto ok;
+	}
+	else {
+		if ( url_cmp(&mh1->d.map->map.src,&u) == 0 )
+			goto ok;
+	}
+	p_str = "check_mappath_mh(3)";
+	goto panic;
+ok:
+	free_url(&u);
+	before = 0;
+	for ( mh1 = mh ; mh1 ; mh1 = mh1->next ) {
+		if ( mh1->dir == MHD_FORWARD ) {
+			n = &mh1->d.map->map.src;
+			_n = &mh1->d.map->map.dest;
+		}
+		else {
+		 	n = &mh1->d.map->map.dest;
+		 	_n = &mh1->d.map->map.src;
+		 }
+		if ( before ) {
+			if ( url_cmp(before,n) ) {
+				p_str = "check_mappath_mh(4)";
+				goto panic;
+			}
+		}
+		before = _n;
+	}
+	return;
+panic:
+	if ( org )
+		ss_printf("PANIC %s: %ls\n",p_str,org);
+	if ( target )
+		ss_printf("PANIC %s: %ls\n",p_str,target);
+	for ( mh1 = mh ; mh1 ; mh1 = mh1->next ) {
+		if ( mh1->dir == MHD_FORWARD )
+			ss_printf(" (%i %ls\n",
+				mh1->dir,
+				get_url_str2(&mh1->d.map->map.src));
+		else	ss_printf(" (%i %ls\n",
+				mh1->dir,
+				get_url_str2(&mh1->d.map->map.dest));
+		ss_printf("    %ls\n",get_url_str2(&mh1->d.map->h.entry));
+		if ( mh1->dir == MHD_FORWARD )
+			ss_printf("    %ls)\n",
+				get_url_str2(&mh1->d.map->map.dest));
+		else	ss_printf("    %ls)\n",
+				get_url_str2(&mh1->d.map->map.src));
+	}
+	ss_printf("PANIC %s --\n",p_str);
+	ss_print_mpr(mpr);
+	er_panic(p_str);
+}
+
+void
+check_mappath_mh(L_CHAR * org,L_CHAR * target,MAP_HISTORY * mh,MP_ROUTE * mpr)
+{
+	_check_mappath_mh(org,target,mh,mpr);
+}
 
 
 int
@@ -1934,7 +2133,11 @@ MAP_HISTORY * mh;
 	get_url2(&u,org);
 	mh = get_mh_from_route(ses,&u,mpr);
 	free_url(&u);
+
+// check_mappath_mh(org,target,mh,mpr);
+
 	flush_route(mpr);
+
 	return mh;
 }
 
