@@ -148,7 +148,9 @@ MAP * m;
 BROWSE_WORK bw1;
 int ret,this_coord;
 MAP_HISTORY * mh;
-GB_RECT g;
+GB_RECT * g;
+int g_len,i;
+
 	ret = 0;
 	this_coord = 0;
 
@@ -196,10 +198,15 @@ GB_RECT g;
 		setup_minrect(m);
 		if ( bw->type != BWT_ROUTE || bw->rr->check ||
 				bw->route_len == 2 ) {
-			g = get_surp_rect(&bw->surp,r);
-			if  ( check_nan_rect(&m->map_file->h.minrect) == 0 &&
-				cross_rect_rect(
-					&m->map_file->h.minrect,&g) != 1 ) {
+			g = get_surp_rect(&g_len,&bw->surp,r);
+			if  ( check_nan_rect(&m->map_file->h.minrect) == 0 ) {
+				for ( i = 0 ; i < g_len ; i ++ ) {
+					if ( cross_rect_rect(
+							&m->map_file->h.minrect,&g[i])
+							== 0 )
+						continue;
+					goto g_ok;
+				}
 
 				lock_task(res_lock);
 				m->flags &= ~MF_BROWSE;
@@ -207,9 +214,15 @@ GB_RECT g;
 
 				if ( bw->route_len == 2 )
 					bw->rr->last_check = -1;
-				if ( bw->type != BWT_ROUTE || bw->rr->check )
+				if ( bw->type != BWT_ROUTE || bw->rr->check ) {
+					if ( g )
+						d_f_ree(g);
 					continue;
+				}
+			g_ok:	;
 			}
+			if ( g )
+				d_f_ree(g);
 		}
 		if ( m->src == 0 ) {
 			m->src = load_resource(bw->ses,&m->src_url,Q_PRI_OBJ);
@@ -226,17 +239,28 @@ GB_RECT g;
 		unlock_task(res_lock,"write_lock");
 		if ( bw->type != BWT_ROUTE || bw->rr->check ||
 				bw->route_len == 2 ) {
-		GB_RECT sr;
-			sr = get_surp_rect(&bw1.surp,r);
-			if  ( check_nan_rect(&m->src->h.minrect) == 0 &&
-				cross_rect_rect(
-				&m->src->h.minrect,&sr) != 1 ) {
+		GB_RECT *sr;
+		int sr_len;
+			sr = get_surp_rect(&sr_len,&bw1.surp,r);
+			if  ( check_nan_rect(&m->src->h.minrect) == 0 ) {
+				for ( i = 0 ; i < sr_len ; i ++ ) {
+					if ( cross_rect_rect(
+						&m->src->h.minrect,&sr[i]) == 0 )
+						continue;
+					goto sr_ok;
+				}
 				if ( bw->route_len == 2 )
 					bw->rr->last_check = -1;
 				if ( bw->type != BWT_ROUTE || 
-					bw->rr->check )
+					bw->rr->check ) {
+					if ( sr )
+						d_f_ree(sr);
 					continue;
+				}
+			sr_ok:	;
 			}
+			if ( sr )
+				d_f_ree(sr);
 		}
 		bw1.mh = add_mh(bw->mh,mh = new_mh(m->map_file,MHD_REVERSE));
 		free_mh(mh);
@@ -281,7 +305,9 @@ load_children_map(RESOURCE * r,BROWSE_WORK * bw)
 MAP * m;
 LOAD_RESOURCE_WORK * ret;
 int len;
-GB_RECT g;
+GB_RECT *g;
+int g_len;
+int i;
 
 int cnt;
 cnt = 0;
@@ -301,7 +327,7 @@ cnt ++;
 				l_string(std_cm,".crd")) == 0 )
 			continue;
 
-		g = get_surp_rect(&bw->surp,r);
+		g = get_surp_rect(&g_len,&bw->surp,r);
 /*
 if ( l_strcmp(r->h.entry.resource,l_string(std_cm,"05.crd")) == 0 )
 ss_printf("***************************\n");
@@ -321,12 +347,17 @@ m->cindex_time - m->mod_time);
 		}
 */
 		if ( m->cindex_mr.tl.x <= m->cindex_mr.br.x ) {
-			if ( cross_rect_rect(&m->cindex_mr,&g) == 0 ) {
-				lock_task(res_lock);
-				m->flags &= ~MF_BROWSE;
-				unlock_task(res_lock,"write_lock");
-				continue;
+			for ( i = 0 ; i < g_len ; i ++ ){
+				if ( cross_rect_rect(&m->cindex_mr,&g[i]) )
+					goto cross_next;
 			}
+			lock_task(res_lock);
+			m->flags &= ~MF_BROWSE;
+			unlock_task(res_lock,"write_lock");
+			if ( g )
+				d_f_ree(g);
+			continue;
+		cross_next:	;
 		}
 
 		if ( m->src == 0 ) {
@@ -342,6 +373,8 @@ m->cindex_time - m->mod_time);
 			bw->load_max --;
 		}
 
+		if ( g )
+			d_f_ree(g);
 
 	}
 
@@ -356,7 +389,9 @@ MAP * m;
 BROWSE_WORK bw1;
 int ret,this_coord;
 MAP_HISTORY * mh;
-GB_RECT g;
+GB_RECT * g;
+int g_len;
+int i;
 int len;
 LOAD_RESOURCE_WORK * wp;
 
@@ -400,18 +435,28 @@ LOAD_RESOURCE_WORK * wp;
 		}
 
 /***/
-		g = get_surp_rect(&bw->surp,r);
-		if  ( check_nan_rect(&m->map_file->h.minrect) == 0 &&
-			cross_rect_rect(
-				&m->map_file->h.minrect,&g) != 1 ) {
+		g = get_surp_rect(&g_len,&bw->surp,r);
+		if  ( check_nan_rect(&m->map_file->h.minrect) == 0 ) {
+			for ( i = 0 ; i < g_len ; i ++ ) {
+				if ( cross_rect_rect(
+					&m->map_file->h.minrect,&g[i]) == 0 )
+					continue;
+				goto c_next;
+			}
 			lock_task(res_lock);
 			m->flags &= ~MF_BROWSE;
 			unlock_task(res_lock,"write_lock");
 				if ( bw->route_len == 2 )
 				bw->rr->last_check = -1;
-			if ( bw->type != BWT_ROUTE || bw->rr->check )
+			if ( bw->type != BWT_ROUTE || bw->rr->check ) {
+				if ( g )
+					d_f_ree(g);
 				continue;
+			}
+		c_next:	;
 		}
+		if ( g )
+			d_f_ree(g);
 		if ( m->src == 0 ) {
 			m->src = get_lrw(w,&m->src_url);
 
@@ -500,7 +545,9 @@ MAP * m;
 BROWSE_WORK bw1;
 int ret,this_coord;
 MAP_HISTORY * mh;
-GB_RECT g;
+GB_RECT * g;
+int g_len;
+int i;
 	ret = 0;
 	this_coord = 0;
 
@@ -524,18 +571,29 @@ GB_RECT g;
 		if ( m->map_file == 0 ) {
 			continue;
 		}
-		g = get_surp_rect(&bw->surp,r);
-		if  ( check_nan_rect(&m->map_file->h.minrect) == 0 &&
-			cross_rect_rect(
-				&m->map_file->h.minrect,&g) != 1 ) {
+		g = get_surp_rect(&g_len,&bw->surp,r);
+		if  ( check_nan_rect(&m->map_file->h.minrect) == 0 ) {
+			for ( i = 0 ; i < g_len ; i ++ ) {
+				if ( cross_rect_rect(
+					&m->map_file->h.minrect,&g[i]) == 0 )
+					continue;
+				goto cc_next;
+			}
 			lock_task(res_lock);
 			m->flags &= ~MF_BROWSE;
 			unlock_task(res_lock,"browse_children_obj");
 				if ( bw->route_len == 2 )
 				bw->rr->last_check = -1;
-			if ( bw->type != BWT_ROUTE || bw->rr->check )
+			if ( bw->type != BWT_ROUTE || bw->rr->check ) {
+				if ( g )
+					d_f_ree(g);
 				continue;
+			}
+		cc_next:;
 		}
+		if ( g )
+			d_f_ree(g);
+
 		if ( m->src == 0 ) {
 			m->src = load_resource(bw->ses,&m->src_url,Q_PRI_OBJ);
 			if ( m->src == 0 )
@@ -635,16 +693,28 @@ MAP_HISTORY * mh;
 			bw1.surp.ptr,bw1.surp.reso,SURP_NOS);
 		if ( bw->type != BWT_ROUTE || bw->rr->check ||
 				bw->route_len == 2) {
-		GB_RECT	sr;
-			sr = get_surp_rect(&bw1.surp,m->dest);
-			if ( check_nan_rect(&m->dest->h.minrect) == 0 &&
-				cross_rect_rect(
-				&m->dest->h.minrect,&sr) != 1 ) {
+		GB_RECT	* sr;
+		int sr_len;
+		int i;
+			sr = get_surp_rect(&sr_len,&bw1.surp,m->dest);
+			if ( check_nan_rect(&m->dest->h.minrect) == 0 ) {
+				for ( i = 0 ; i < sr_len ; i ++ ) {
+					if ( cross_rect_rect(
+						&m->dest->h.minrect,&sr[i]) == 0 )
+						continue;
+					goto sr_ok;
+				}
 				if ( bw->route_len == 2 )
 					bw->rr->last_check = -1;
-				if ( bw->type != BWT_ROUTE || bw->rr->check )
+				if ( bw->type != BWT_ROUTE || bw->rr->check ) {
+					if ( sr )
+						d_f_ree(sr);
 					continue;
+				}
+			sr_ok:	;
 			}
+			if ( sr )
+				d_f_ree(sr);
 		}
 		lock_task(res_lock);
 		m->flags &= ~MF_BROWSE;
@@ -884,6 +954,20 @@ int ret;
 	}
 }
 
+void
+limit_reso_control(
+	REAL1 * dest,
+	REAL1 src)
+{
+#define LR_RESO 	0.99
+#define LR_SRC_RESO 	2
+	if ( *dest < src )
+		*dest = src* LR_SRC_RESO;
+	else {
+		*dest = (*dest) * LR_RESO + src * (1-LR_RESO);
+	}
+}
+
 void
 draw_coordinate(
 	GBVIEW_FLAME * gf,
@@ -896,12 +980,16 @@ int i;
 GB_POINT center;
 REAL1 radius;
 extern int spiral_count;
-GB_RECT sr;
+GB_RECT * sr;
+int sr_len;
 int f;
 
 int reso_cnt,minus_cnt,rect_cnt;
+int proc;
 
 
+	proc = 0;
+
 	dw->limit_reso = 0;
 	if ( dw->pt_list &&
 	     (r->c.geometory_type & GT_T_MASK) == GT_T_GLOBE_SUR )
@@ -910,6 +998,7 @@ int reso_cnt,minus_cnt,rect_cnt;
 			r->h.minrect.tl.x,
 			dw->pt_list,
 			dw->pt_reso,
+			0,
 			dw->size);
 
 	lock_task(res_lock);
@@ -918,22 +1007,40 @@ int reso_cnt,minus_cnt,rect_cnt;
 			m1 != (MAP*)&r->c.map_children ;
 			m1 = R_NEXT(MAP*,&m1->h) ) {
 
-		if ( m1->flags & MF_BROWSE )
+		if ( m1->flags & MF_BROWSE ) {
+			proc = 1;
 			continue;
-		if ( m1->src == 0 )
+		}
+		if ( m1->src == 0 ) {
+			if ( l_strcmp(&m1->src_url.resource
+					[l_strlen(m1->src_url.resource)-4],
+					l_string(std_cm,".crd")) )
+				proc = 2;
 			continue;
-		if ( m1->map_file == 0 )
+		}
+		if ( m1->map_file == 0 ) {
+			if ( l_strcmp(&m1->src_url.resource
+					[l_strlen(m1->src_url.resource)-4],
+					l_string(std_cm,".crd")) )
+				proc = 3;
 			continue;
+		}
 		if ( m1->src->h.type == RT_COORDINATE )
 			continue;
+		proc = 4;
 		if ( (m1->src->h.flags & RF_INDICATE) == RF_I_OFF )
 			continue;
 		setup_minrect(m1);
 
-		sr = get_surp_rect(&dw->surp,r);
-		if  ( check_nan_rect(&m1->map_file->h.minrect) == 0 &&
-			cross_rect_rect(
-			&m1->map_file->h.minrect,&sr) != 1 ) {
+		sr = get_surp_rect(&sr_len,&dw->surp,r);
+		if  ( check_nan_rect(&m1->map_file->h.minrect) == 0 ) {
+			for ( i = 0 ; i < sr_len ; i ++ ) {
+				if ( cross_rect_rect(
+						&m1->map_file->h.minrect,&sr[i])
+						== 0 )
+					continue;
+				goto sr_ok;
+			} 
 
 			if ( m1->src->h.type == RT_DRAW_GB ) {
 				if ( m1->src->draw_gb.hit_outofcircle
@@ -943,8 +1050,14 @@ int reso_cnt,minus_cnt,rect_cnt;
 				}
 				else m1->src->draw_gb.hit_outofcircle ++;
 			}
+			if ( sr )
+				d_f_ree(sr);
 			continue;
+		sr_ok:	;
 		}
+		if ( sr )
+			d_f_ree(sr);
+
 		if ( m1->src->h.type == RT_DRAW_GB )
 			m1->src->draw_gb.hit_outofcircle = 0;
 		dw1.limit_reso = -1;
@@ -1011,6 +1124,7 @@ rect_cnt ++;
 			if ( f == 0 ) {
 				d_f_ree(dw1.pt_list);
 				d_f_ree(dw1.pt_reso);
+				proc = 6;
 				continue;
 			}
 
@@ -1039,6 +1153,7 @@ rect_cnt ++;
 		default:
 			er_panic("no support");
 		}
+
 		if ( dw1.limit_reso >= 0 ) {
 			map_conv_forward(m1->map_file,
 				&dw1.limit_ptr,
@@ -1050,14 +1165,19 @@ rect_cnt ++;
 			}
 		}
 	}
+	if ( proc == 0 && dw->limit_reso == 0 )
+			dw->limit_reso = r->h.visible_resolution*2;
 	if ( r->c.flags & CF_FIX_LIMIT_RESO ) {
-		if ( dw->limit_reso && 
+		if ( dw->limit_reso &&
 				r->c.limit_resolution > dw->limit_reso )
-			r->c.limit_resolution = dw->limit_reso;
+			limit_reso_control(
+				&r->c.limit_resolution,
+				dw->limit_reso);
 	}
 	else if ( dw->limit_reso )
-		r->c.limit_resolution = dw->limit_reso;
-
+		limit_reso_control(
+				&r->c.limit_resolution,
+				dw->limit_reso);
 	unlock_task(res_lock,"draw_coordinate");
 }
 
