@@ -49,7 +49,8 @@ typedef struct dm_t {
 typedef struct dm_time_list {
 	struct dm_time_list *	next;
 	L_CHAR *		key;
-	STREAM *		s;
+	XL_SEXP *		aboat_target;
+	URL			target_url;
 	int			time;
 	int			start_time;
 } DM_TIME_LIST;
@@ -182,10 +183,16 @@ dm_gc_obj()
 void
 gc_dm()
 {
+DM_TIME_LIST * tl;
+	for ( tl = tlist ; tl ; tl = tl->next ) {
+		if ( tl->aboat_target == 0 )
+			continue;
+		gc_gb_sexp(tl->aboat_target);
+	}
 }
 
 DM_TIME_LIST *
-_get_tlist(L_CHAR * key)
+_get_tlist(L_CHAR * key,URL * target_url)
 {
 DM_TIME_LIST * ret;
 	for ( ret = tlist ; ret ; ret = ret->next )
@@ -194,6 +201,7 @@ DM_TIME_LIST * ret;
 	ret = d_alloc(sizeof(*ret));
 	memset(ret,0,sizeof(*ret));
 	ret->key = ll_copy_str(key);
+	copy_url(&ret->target_url,target_url);
 
 	ret->next = tlist;
 	tlist = ret;
@@ -202,11 +210,11 @@ DM_TIME_LIST * ret;
 }
 
 DM_TIME_LIST *
-get_tlist(L_CHAR * key)
+get_tlist(L_CHAR * key,URL * target_url)
 {
 DM_TIME_LIST * ret;
 	lock_task(dm_lock);
-	ret = _get_tlist(key);
+	ret = _get_tlist(key,target_url);
 	unlock_task(dm_lock,"get_tlist");
 	return ret;
 }
@@ -271,11 +279,12 @@ _aboat_dm_loading()
 DM_TIME_LIST * tl;
 
 	for ( tl = tlist ; tl ; tl = tl->next ) {
-		if ( tl->s == 0 )
+		if ( tl->aboat_target == 0 )
 			continue;
-		s_close(tl->s);
-		for ( ; tl->s ; ) {
-			sleep_task((int)&tl->s,dm_lock);
+		np_divide_p_agent(&tl->target_url);
+		aboat_session(tl->aboat_target);
+		for ( ; tl->aboat_target ; ) {
+			sleep_task((int)&tl->aboat_target,dm_lock);
 			lock_task(dm_lock);
 		}
 	}
@@ -438,9 +447,9 @@ L_CHAR * key;
 				break;
 		}
 		lock_task(dm_lock);
-		tl = _get_tlist(n->h.key);
+		tl = _get_tlist(n->h.key,&r->h.target);
 		tl->time = n->handle_time;
-		tl->s = get_sexp_stream(ld);
+		tl->aboat_target = ld;
 		tl->start_time = get_xltime();
 		unlock_task(dm_lock,"dm_loading_task");
 
@@ -451,8 +460,8 @@ L_CHAR * key;
 
 
 		lock_task(dm_lock);
-		tl->s = 0;
-		wakeup_task((int)&tl->s);
+		tl->aboat_target = 0;
+		wakeup_task((int)&tl->aboat_target);
 		tl->start_time = 0;
 		if ( get_type(pp) != XLT_NULL ) {
 			for ( i = 0 ; i < DM_LIST_SIZE ; i ++ ) {
@@ -1265,7 +1274,7 @@ digging_matrix(
 DM_TIME_LIST * tl;
 L_CHAR * f;
 	lock_task(dm_lock);
-	tl = _get_tlist(f = get_server_key(&res->h.target));
+	tl = _get_tlist(f = get_server_key(&res->h.target),&res->h.target);
 	d_f_ree(f);
 	_digging_matrix(wfid,res,res->draw_gb.dm,r,lev,tl);
 	unlock_task(dm_lock,"digging");
