@@ -383,7 +383,7 @@ int flags;
 	else 	goto typemissmatch;
 
 	get_url2(&i_url,name->string.data);
-	set_pointer_indicate(flags,&i_url);
+	set_pointer_indicate(wf_next_gf(0,GVFM_LIVE),flags,&i_url);
 
 	free_url(&i_url);
 	return 0;
