@@ -380,6 +380,8 @@ TREE_NODE * tn;
 	tc->get_pixels = func_pixels;
 	tc->get_query = func_query;
 	tc->r = r;
+	tc->trans_timeout = INVALID_TRANS_TIMEOUT;
+	tc->cr_err_count = INVALID_TRANS_CR_ERR_COUNT;
 	tc->next = tc_list;
 	tc_list = tc;
 }
@@ -471,10 +473,11 @@ int cr_err_q;
 			if ( nr_time == 0 )
 				nr_time = get_xltime();
 	
-			if ( get_xltime() - nr_time > INVALID_TRANS_TIMEOUT ) {
+			if ( get_xltime() - nr_time > n1->tc->trans_timeout ) {
 				if ( nr_count == 0 ) {
 					np_divide_p_agent(&r->h.entry);
 					aboat_session(n1->data);
+					n1->tc->trans_timeout *= 2;
 					nr_count = 1;
 				}
 ss_printf("** ** * RESET STREAM %i - %i\n",nr_count,wir);
@@ -484,6 +487,9 @@ ss_printf("** ** * RESET STREAM %i - %i\n",nr_count,wir);
 		else {
 			nr_count = 0;
 			nr_time = 0;
+			n1->tc->trans_timeout --;
+			if ( n1->tc->trans_timeout < INVALID_TRANS_TIMEOUT )
+				n1->tc->trans_timeout = INVALID_TRANS_TIMEOUT;
 		}
 
 		switch ( get_type(n1->data) ) {
@@ -535,22 +541,29 @@ ss_printf("** ** * RESET STREAM %i - %i\n",nr_count,wir);
 			else {
 				cr_err_count = 0;
 				cr_err_count_flag = 0;
+				n1->tc->cr_err_count --;
+				if ( n1->tc->cr_err_count 
+					< INVALID_TRANS_CR_ERR_COUNT )
+					n1->tc->cr_err_count = 
+						INVALID_TRANS_CR_ERR_COUNT;
 			}
 			data = cdr(data);
 			if ( get_xltime() - t >= 2 )
 				n3 = tc_dirty_insert(n3,n2);
 		}
-		tc_dirty_insert(n3,0);
-		free_tc_t(n1,0);
 
-		if ( cr_err_count > INVALID_TRANS_CR_ERR_COUNT &&
+		if ( cr_err_count > n1->tc->cr_err_count &&
 			cr_err_count_flag == 0 ) {
 			np_divide_p_agent(&r->h.entry);
 			aboat_session(n1->data);
 			cr_err_count_flag = 1;
 			cr_err_q = QUEUE_LENGTH;
+			n1->tc->cr_err_count *= 2;
 		}
 
+		tc_dirty_insert(n3,0);
+		free_tc_t(n1,0);
+
 		gc_pop(0,0);
 		continue;
 	n1_free:
