@@ -28,9 +28,7 @@
 #include	"utils.h"
 #include	"radar.h"
 
-void load_task();
 void change_task();
-void exit_task();
 void load_structure_task();
 void test_gbtask();
 void ipc_task();
@@ -102,16 +100,12 @@ extern int main_tid;
 
 
 	ret = 0;
-	for ( i = 0 ; i < LOAD_TASK_MAX ; i ++ )
-		create_task(load_task,0,PRI_DRAW);
-	create_task(load_structure_task,0,PRI_FETCH);
 	create_task(change_task,0,PRI_DRAW_EXIT);
-	create_task(exit_task,0,PRI_DRAW_EXIT);
 
 	main_tid = get_tid();
-
+/* sethomestatus
 	set_opening_state(OS_SETHOME);
-
+*/
 	gc_push(0,0,"start_gbview(1)");
 	q = n_get_symbol("gv-insert-query");
 	set_attribute(q,l_string(std_cm,"type"),
@@ -120,8 +114,9 @@ extern int main_tid;
 	er = gv_is_insert_query(gblisp_top_env0,
 		List(q,setup_initial_query,-1),0,q->symbol.field);
 	gc_pop(0,0);
-
+/* sethomestatus
 	set_opening_state(OS_SETHOME_COMPLETE);
+*/
 	return ret;
 }
 
