@@ -102,7 +102,7 @@ set_t_msg(55);
 		gf->flame_base_display_map.dir = MHD_REVERSE;
 		gf->flame_base_display_map.type = MHT_LINEAR;
 		gf->flame_base_display_map.next = 0;
-		calc_pitch(gf,1);
+		_calc_pitch(gf,1);
 	}
 
 	for ( wfp = &gf->flame ; *wfp ; wfp = &(*wfp)->next ) {
