@@ -94,7 +94,7 @@ win_flame_move(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from,VPOINT to,void * ix)
 
 
 int
-change_win_flame(GBVIEW_FLAME * gf,WIN_FLAME * wf,int geo_type,int wf_type)
+_change_win_flame(GBVIEW_FLAME * gf,WIN_FLAME * wf,int geo_type,int wf_type)
 {
 WIN_FLAME_TABLE * tbl;
 int ret;
@@ -115,6 +115,16 @@ next:
 	return ret;
 }
 
+int
+change_win_flame(GBVIEW_FLAME * gf,WIN_FLAME * wf,int geo_type,int wf_type)
+{
+int ret;
+	wf_lock(gf);
+	ret = _change_win_flame(gf,wf,geo_type,wf_type);
+	wf_unlock(gf);
+	return ret;
+}
+
 int
 win_flame_redraw(GBVIEW_FLAME * gf,WIN_FLAME * wf)
 {
