@@ -89,7 +89,7 @@ ACRP_DIR * d;
 	tt = new_mpt();
 	tt->next = t;
 
-	tt->ent[0].pri = ll_copy_str(pri,123);
+	tt->ent[0].pri = ll_copy_str(pri);
 	tt->ent[0].sum = sum;
 	d = &tt->ent[0].dir[0];
 	d->hops = dir;
@@ -102,7 +102,7 @@ ACRP_DIR * d;
 	for ( ; old_len < len ; old_len ++ ) {
 		tt = new_mpt();
 		tt->next = t;
-		tt->ent[0].pri = ll_copy_str(pri,124);
+		tt->ent[0].pri = ll_copy_str(pri);
 		tt->ent[0].sum = sum;
 		d = &tt->ent[0].dir[0];
 		d->hops = dir;
@@ -202,7 +202,7 @@ int * ret;
 int len,i;
 MAP_PATH_TABLE * t;
 	for ( len = 0 , t = m->mpt ; t ; t = t->next, len ++ );
-	ret = d_alloc(sizeof(int)*(len+1),12);
+	ret = d_alloc(sizeof(int)*(len+1));
 	ret[0] = len;
 	for ( t = m->mpt , i = 1 ; t ; t = t->next , i ++ ) {
 		ret[i] = t->id;
@@ -223,11 +223,11 @@ int ret;
 	if ( e2->dir[0].hops < 0 )
 		return 0;
 	if ( e1->dir[0].hops < 0 ) {
-		e1->pri = ll_copy_str(e2->pri,1417);
+		e1->pri = ll_copy_str(e2->pri);
 		e1->sum = e2->sum;
 		e1->dir[0] = e2->dir[0];
-		e1->dir[0].map = ll_copy_str(map,1416);
-		e1->dir[0].crd = ll_copy_str(crd,1415);
+		e1->dir[0].map = ll_copy_str(map);
+		e1->dir[0].crd = ll_copy_str(crd);
 		e1->dir[0].flags |= ADF_CHECK;
 		return 1;
 	}
@@ -263,8 +263,8 @@ int ret;
 		for ( j = ACRP_DIR_NOS-1 ; j > i ; j -- )
 			e1->dir[j] = e1->dir[j-1];
 		e1->dir[i] = e2->dir[0];
-		e1->dir[i].map = ll_copy_str(map,1414);
-		e1->dir[i].crd = ll_copy_str(crd,1413);
+		e1->dir[i].map = ll_copy_str(map);
+		e1->dir[i].crd = ll_copy_str(crd);
 		e1->dir[i].flags |= ADF_CHECK;
 		return ret;
 	}
@@ -275,11 +275,11 @@ int ret;
 		for ( i = 0 ; i < ACRP_DIR_NOS ; i ++ )
 			free_mpt_entry_dir(&e1->dir[i]);
 		d_f_ree(e1->pri);
-		e1->pri = ll_copy_str(e2->pri,1412);
+		e1->pri = ll_copy_str(e2->pri);
 		e1->sum = e2->sum;
 		e1->dir[0] = e2->dir[0];
-		e1->dir[0].map = ll_copy_str(map,1411);
-		e1->dir[0].crd = ll_copy_str(crd,1410);
+		e1->dir[0].map = ll_copy_str(map);
+		e1->dir[0].crd = ll_copy_str(crd);
 		e1->dir[0].flags |= ADF_CHECK;
 		return ret;
 	}
@@ -324,8 +324,8 @@ ACRP_DIR * d;
 			d_f_ree(d->map);
 		if ( d->crd )
 			d_f_ree(d->crd);
-		d->map = ll_copy_str(map,1409);
-		d->crd = ll_copy_str(crd,1408);
+		d->map = ll_copy_str(map);
+		d->crd = ll_copy_str(crd);
 		d->flags |= ADF_CHECK;
 		for ( j = 1 ; j < ACRP_DIR_NOS ; j ++ )
 			free_mpt_entry_dir(&e->dir[j]);
@@ -405,7 +405,7 @@ L_CHAR * dpri;
 		if ( dpri && m1->ent[i].dir[0].hops == 0 ) {
 			if ( m1->ent[i].pri )
 				d_f_ree(m1->ent[i].pri);
-			m1->ent[i].pri = ll_copy_str(dpri,1407);
+			m1->ent[i].pri = ll_copy_str(dpri);
 		}
 		if ( pri == 0 )
 			pri = m1->ent[i].pri;
@@ -431,10 +431,10 @@ ACRP_DIR * d;
 			if ( d->hops == 0 ) {
 				if ( d->map )
 					d_f_ree(d->map);
-				d->map = ll_copy_str(map,1406);
+				d->map = ll_copy_str(map);
 				if ( d->crd )
 					d_f_ree(d->crd);
-				d->crd = ll_copy_str(crd,1405);
+				d->crd = ll_copy_str(crd);
 			}
 			if ( l_strcmp(d->crd,me) == 0 ) {
 				free_mpt_entry_dir(d);
@@ -540,10 +540,10 @@ set_cpu_msg(304);
 			mpt = optimizing_mpt(mpt);
 			count_up_hops(mpt,map,src,dest);
 		}
-		aa = d_alloc(sizeof(*aa),1);
-		aa->map = ll_copy_str(map,1404);
-		aa->crd = ll_copy_str(src,1403);
-		aa->me = ll_copy_str(dest,1402);
+		aa = d_alloc(sizeof(*aa));
+		aa->map = ll_copy_str(map);
+		aa->crd = ll_copy_str(src);
+		aa->me = ll_copy_str(dest);
 		aa->mpt = mpt;
 		aa->next = a;
 		a = aa;
@@ -568,10 +568,10 @@ set_cpu_msg(310);
 			count_up_hops(mpt,map,dest,src);
 		}
 set_cpu_msg(311);
-		aa = d_alloc(sizeof(*aa),1);
-		aa->map = ll_copy_str(map,1401);
-		aa->crd = ll_copy_str(dest,1400);
-		aa->me = ll_copy_str(src,1399);
+		aa = d_alloc(sizeof(*aa));
+		aa->map = ll_copy_str(map);
+		aa->crd = ll_copy_str(dest);
+		aa->me = ll_copy_str(src);
 		aa->mpt = mpt;
 		aa->next = a;
 		a = aa;
@@ -729,11 +729,11 @@ set:
 	if ( e->dir[0].hops >= 0 ) {
 		if ( l_strcmp(e->pri,m->my_pri) > 0 ) {
 			d_f_ree(e->pri);
-			e->pri = ll_copy_str(m->my_pri,1397);
+			e->pri = ll_copy_str(m->my_pri);
 		}
 	}
 	else {
-		e->pri = ll_copy_str(m->my_pri,1396);
+		e->pri = ll_copy_str(m->my_pri);
 		e->sum = 1;
 	}
 	for ( i = 0 ; i < ACRP_DIR_NOS ; i ++ )
@@ -766,7 +766,7 @@ int i;
 		if ( t->next == 0 )
 			break;
 		if ( *flp == 0 ) {
-			*flp = fl1 = d_alloc(sizeof(*fl1),1);
+			*flp = fl1 = d_alloc(sizeof(*fl1));
 			fl1->next = 0;
 			for ( i = 0 ; i < ACRP_SUBID_NOS ; i ++ )
 				fl1->list[i] = 0;
@@ -898,11 +898,11 @@ set:
 	if ( e->dir[0].hops >= 0 ) {
 		if ( l_strcmp(e->pri,m->my_pri) > 0 ) {
 			d_f_ree(e->pri);
-			e->pri = ll_copy_str(m->my_pri,1395);
+			e->pri = ll_copy_str(m->my_pri);
 		}
 	}
 	else {
-		e->pri = ll_copy_str(m->my_pri,1394);
+		e->pri = ll_copy_str(m->my_pri);
 		e->sum = 1;
 	}
 	for ( i = 0 ; i < ACRP_DIR_NOS ; i ++ )
