@@ -66,20 +66,22 @@ int len;
 }
 
 
+
 void
 make_lump_dir(unsigned int id)
 {
 int i;
 char * path;
 int len;
-	path = make_base_dir();
-	len = strlen(path);
-	path = d_re_alloc(path,len + 100);
+char * base;
+	base = make_base_dir();
+	path = d_alloc(strlen(base)+128);
+	strcpy(path, base);
 	for ( i = 0 ; i < 4 ; i ++ ) {
-		sprintf(&path[len],"/%i",(id>>(8*(3-i)))&0x0ff);
+		sprintf(&path[strlen(path)],"/%i",(id>>(8*(3-i)))&0x0ff);
 		u_mkdir(path,0755);
-		len = strlen(path);
 	}
+	d_f_ree(path);
 }
 
 
