@@ -35,13 +35,13 @@ static int MPct_ses = -1;
 
 ss_printf("Set send_cindex %ls\n",crd);
 
-	fcrd = ll_copy_str(crd,235);
+	fcrd = ll_copy_str(crd);
 	q = l_strlen(fcrd)-1;
 	for ( ; q >= 0 && fcrd[q] != '.' ; q -- );
 	if ( q >= 0 )
 		fcrd[q] = 0;
 
-	get_url2(&u,l_string(std_cm,"xlp://localhost:9100/"),1218);
+	get_url2(&u,l_string(std_cm,"xlp://localhost:9100/"));
 	u.port = get_mp_port();
 	if ( u.port == 0 ) {
 		goto end;
