@@ -45,11 +45,24 @@ typedef struct XLoHTTP_header {
 #define XoH_T_LAST		3
 #define XoH_T_ERROR		4
 #define XoH_T_KEEP_ALIVE	5
+#define XoH_T_TESTING_VER	6
+#define XoH_T_UPLOAD_SESSION	7
+#define XoH_T_DOWNLOAD_SESSION	8
 	unsigned char		sum;
 	short			seq;
 	unsigned int		cockie[2];
 } XLoHTTP_HEADER;
 
+typedef struct XoH_list {
+	struct XoH_list *	next;
+	STREAM *		con;
+	XLoHTTP_HEADER		h;
+	HTTP_INFO		info;
+	unsigned int		tim;
+} XoH_LIST;
+
+
+
 int scan_HTTP(HTTP_INFO * info,STREAM * con,int flag);
 void free_HTTP_info(HTTP_INFO *);
 int new_accept(STREAM **,ACCESS_KEY *,XL_INTERPRETER *,PERMISSION_LIST *);
