@@ -717,7 +717,7 @@ typedef struct pn_rs_draw_gb {
 	GB_POINT	pitch_list[32];
 	int		loop_no;
 /* cut
-	INFO_REQ_QUEUE * ir_queue;
+	INFO_REQ_QUEUE * ir_que;
 */
 /* INFO_SCHEME record
 	INFO_SCHEME *	ischeme;
