@@ -163,13 +163,27 @@ typedef union overlay {
 	OV_CSUPERINPOSE		cs;
 } OVERLAY;
 
-
+#define GROUP_ID		unsigned short
 
 typedef struct surp_set {
 	GB_POINT		ptr[SURP_NOS];
 	REAL1			reso[SURP_NOS];
+	GROUP_ID		group[SURP_NOS];
 } SURP_SET;
 
+typedef struct group_set_list {
+	struct group_set_list *	next;
+	int			x_cnt;
+	int			y_cnt;
+	GROUP_ID		prev_gid;
+	GROUP_ID		gid;
+} GROUP_SET_LIST;
+
+typedef struct group_set {
+	GROUP_ID		next_id;
+	GROUP_SET_LIST *	list;
+} GROUP_SET;
+
 typedef struct obj_header {
 	unsigned int	code;
 #define MAIN_CODE	0xffffff00
@@ -321,6 +335,7 @@ typedef struct res_header {
 
 #define RF_CACHE		0x00000010
 #define RF_UNCACHE		0x00000020
+#define RF_ERROR		0x00000040
 
 #define RF_COMPLETE		0x00000100
 #define RF_LOAD_EXTEND		0x00000200
@@ -916,15 +931,16 @@ void setup_c_unit(COORDINATE_UNIT * up,int ses,L_CHAR * url,
 COORDINATE_UNIT * search_c_unit(L_CHAR * url);
 
 void set_surp(SURP_SET *,GB_RECT * ,REAL1 reso);
-GB_RECT get_surp_rect(SURP_SET *,RESOURCE *);
-GB_RECT get_surp_rect_rate(SURP_SET * surp,REAL1 rate,RESOURCE *r);
+GB_RECT * get_surp_rect(int *,SURP_SET *,RESOURCE *);
+GB_RECT * get_surp_rect_rate(int *,SURP_SET * surp,REAL1 rate,RESOURCE *r);
 REAL1 get_surp_reso(SURP_SET * surp);
 int resource_check(L_CHAR * url_str,int);
 void dispose_lrw(LOAD_RESOURCE_WORK * w,int terminate);
+void test_map_reso(char* str,REAL1 * reso,int size,int data);
 
 void
 adjust_lambda(L_CHAR * unit,REAL1 min_point,
-	GB_POINT * pt_list,REAL1 * reso,int size);
+	GB_POINT * pt_list,REAL1 * reso,GROUP_ID * group,int size);
 
 /*
 extern RING_TYPE	resource_h;
