@@ -164,6 +164,31 @@ typedef struct s_XLoHTTP {
 	S_XLoHTTP_INFO *	info;
 } S_XLoHTTP;
 
+
+typedef struct s_XLoHTTP_info_2 {
+	int			flags;
+#define XoH_F2_BUFFER			0x00000001
+#define XoH_F2_CLOSE		0x00000002
+	char *			proxy_server;
+	unsigned int		proxy_ip;
+	int			proxy_port;
+
+	char *			target_server;
+	unsigned int		target_ip;
+	int			target_port;
+	unsigned int		cockie[2];
+	int			remain_size;
+#define MAX_REMAIN_SIZE			100000000
+	union stream *		upload_st;
+	union stream *		download_st;
+	STREAM_BUF		upload_buf;
+} S_XLoHTTP_INFO_2;
+
+typedef struct s_XLoHTTP_2 {
+	S_HEADER		h;
+	S_XLoHTTP_INFO_2 *	info;
+} S_XLoHTTP_2;
+
 #include	"machine/stream.h"
 
 extern S_FILE __s_std[3];
@@ -188,6 +213,11 @@ STREAM * s_connect_XLoHTTP(
 	char * target_server,int target_ip,short target_port,
 	char * proxy_server,int proxy_ip,short proxy_port,
 	int flags);
+STREAM * s_connect_XLoHTTP_2(
+	int * cerr,
+	char * target_server,int target_ip,short target_port,
+	char * proxy_server,int proxy_ip,short proxy_port,
+	int flags);
 
 void init_stream();
 void s_open(STREAM *,int);
