@@ -148,7 +148,7 @@ A_TREE *
 char_a_tree(L_CHAR from,L_CHAR to)
 {
 A_TREE * at;
-	at = d_alloc(sizeof(*at),123);
+	at = d_alloc(sizeof(*at));
 	at->h.type = ATT_CHAR;
 	at->ch.from = from;
 	at->ch.to = to;
@@ -162,7 +162,7 @@ star_a_tree(A_TREE * a)
 A_TREE * ret;
 	if ( a == 0 )
 		return 0;
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->h.type = ATT_STAR;
 	ret->s.target = a;
 	return ret;
@@ -174,7 +174,7 @@ q_a_tree(A_TREE * a)
 A_TREE * ret;
 	if ( a == 0 )
 		return 0;
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->h.type = ATT_QST;
 	ret->q.target = a;
 	return ret;
@@ -186,7 +186,7 @@ plus_a_tree(A_TREE * a)
 A_TREE * ret;
 	if ( a == 0 )
 		return 0;
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->h.type = ATT_PLUS;
 	ret->p.target = a;
 	return ret;
@@ -202,7 +202,7 @@ A_TREE * ret;
 		free_a_tree(a);
 		return 0;
 	}
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->h.type = ATT_AND;
 	ret->and.a = a;
 	ret->and.b = b;
@@ -219,7 +219,7 @@ A_TREE * ret;
 	}
 	if ( a == 0 )
 		return b;
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->h.type = ATT_OR;
 	ret->or.a = a;
 	ret->or.b = b;
@@ -305,7 +305,7 @@ A_TREE * at,* at2;
 			st = i;
 			if ( skip_punc(rex,&i,'[',']') < 0 )
 				goto err;
-			buf = d_alloc(sizeof(L_CHAR)*(i-st),123);
+			buf = d_alloc(sizeof(L_CHAR)*(i-st));
 			memcpy(buf,&rex[st+1],sizeof(L_CHAR)*(i-st-2));
 			buf[i-st-2] = 0;
 			at = and_a_tree(at,char_class_a_tree(buf));
@@ -315,7 +315,7 @@ A_TREE * at,* at2;
 			st = i;
 			if ( skip_punc(rex,&i,'(',')') < 0 )
 				goto err;
-			buf = d_alloc(sizeof(L_CHAR)*(i-st),1234);
+			buf = d_alloc(sizeof(L_CHAR)*(i-st));
 			memcpy(buf,&rex[st+1],sizeof(L_CHAR)*(i-st-2));
 			buf[i-st-2] = 0;
 			at = and_a_tree(at,make_a_tree(buf));
@@ -447,7 +447,7 @@ AUTOMATON *
 new_automaton()
 {
 AUTOMATON * ret;
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->state_list = 0;
 	return ret;
 }
@@ -457,7 +457,7 @@ A_STATE_SET *
 new_state_set(A_STATE * s)
 {
 A_STATE_SET * ret;
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->state = s;
 	ret->next = 0;
 	return ret;
@@ -478,7 +478,7 @@ A_STATE *
 new_state(AUTOMATON * a)
 {
 A_STATE * ret;
-	ret = d_alloc(sizeof(*ret),123);
+	ret = d_alloc(sizeof(*ret));
 	ret->table_size = 0;
 	ret->table = 0;
 	ret->flags = 0;
@@ -508,11 +508,11 @@ int size;
 A_GOTO * g;
 	ret = new_automaton();
 	for ( s = a->state_list ; s ; s = s->next ) {
-		s1 = d_alloc(sizeof(*s1),234);
+		s1 = d_alloc(sizeof(*s1));
 		s1->state_set = 0;
 		s1->flags = s->flags;
 		s1->table_size = s->table_size;
-		s1->table = d_alloc(sizeof(A_GOTO)*s->table_size,123);
+		s1->table = d_alloc(sizeof(A_GOTO)*s->table_size);
 		memcpy(s1->table,s->table,sizeof(A_GOTO)*s->table_size);
 		s->work_state = s1;
 
@@ -533,7 +533,7 @@ set_goto(A_STATE * s1,L_CHAR from,L_CHAR to,A_STATE * s2)
 A_GOTO * g;
 	if ( s1->table_size == 0 ) {
 		s1->table_size = 1;
-		g = s1->table = d_alloc(sizeof(*g),123);
+		g = s1->table = d_alloc(sizeof(*g));
 	}
 	else {
 		s1->table_size ++;
@@ -750,7 +750,7 @@ A_STATE * s;
 	for ( s = nfa->state_list ; s ; s = s->next ) {
 		if ( !(s->flags & flags ) )
 			continue;
-		ss1 = d_alloc(sizeof(*ss1),123);
+		ss1 = d_alloc(sizeof(*ss1));
 		ss1->state = s;
 		ss1->next = ret;
 		ret = ss1;
@@ -858,7 +858,7 @@ _L_CHAR from,to;
 	ret = 0;
 	to = LC_MAX;
 	for ( ; ; ) {
-		inp = d_alloc(sizeof(*inp),123);
+		inp = d_alloc(sizeof(*inp));
 		inp->to = to;
 		inp->from = get_from(nfa,to);
 		inp->next = ret;
