@@ -95,7 +95,7 @@ SVG_LAYER *svg_make_layer(L_CHAR *id){
 SVG_LAYER *ret;
 
 	ret = (SVG_LAYER *)calloc(sizeof(SVG_LAYER),1);
-	ret->id = ll_copy_str(id,1234); 
+	ret->id = ll_copy_str(id); 
 	return ret;
 }
 
