@@ -22,6 +22,7 @@
 #include	<sys/types.h>
 #include	"r64.h"
 #include	"machine/include.h"
+#include	"u_file.h"
 
 int
 r64_check_level(R64_FILE * f,int level)
@@ -38,7 +39,7 @@ INTEGER64 ret;
 		return 0;
 	ofs = f->level_ofs[level];
 	ofs += f->level_w[level]*f->level_h[level]*ENT_UNIT_VOL(f);
-	ret = lseek64(f->fd,0,SEEK_END);
+	ret = u_lseek64(f->fd,0,SEEK_END);
 	if (ret < ofs )
 		return 0;
 	return 1;
