@@ -21,6 +21,7 @@
 #include	<fcntl.h>
 
 #include	"machine/include.h"
+#include	"pri_level.h"
 #include	"lock_level.h"
 #include	"memory_debug.h"
 #include	"stream.h"
@@ -52,6 +53,7 @@ SEM chunk_read_lock;
 extern SEM stream_lock;
 SEM XLoHTTP_lock,scan_lock;
 
+void check_stream();
 int s_close_XLoHTTP();
 int s_write_XLoHTTP();
 int s_read_XLoHTTP();
@@ -87,6 +89,9 @@ init_XLoHTTP_stream()
 	scan_lock = new_lock(LL_XLoHTTP);
 	chunk_read_lock = new_lock(LL_XLoHTTP);
 	insert_s_table(&s_XLoHTTP_table);
+/*
+      	new_tick(check_stream,5,0);
+*/
 }
 
 CHUNK_READ_LIST *
@@ -321,7 +326,7 @@ int start;
 			if ( er < 1 )
 				return -1;
 /*
-printf("%c",str[p]);
+ss_printf("%c",str[p]);
 */
 			switch ( str[p] ) {
 			case '\r':
@@ -460,7 +465,8 @@ static int counter;
 		s_printf(con,
 			"POST http://%s:%i/cgi-bin/xlsv%i.cgi HTTP/1.1\r\n",
 			server,port,(counter++)&0x0ff);
-	else	s_printf(con,"POST /cgi-bin/xlsv.cgi HTTP/1.0\r\n");
+	else	s_printf(con,"POST http://%s:%i/cgi-bin/xlsv.cgi HTTP/1.0\r\n",
+			server,port);
 	switch ( flags & (XoH_F_PROXY|XoH_F_KEEP_ALIVE) ) {
 	case 0:
 		break;
@@ -656,7 +662,7 @@ int length, result;
 			chunk_read_end(con);
 		s_close(con);
 	}
-	create_task(XLoHTTP_task,(int)ret->xoh.info,1);
+	create_task(XLoHTTP_task,(int)ret->xoh.info,PRI_WRITE_BUF);
 	lock_task(stream_lock);
 	_s_open(ret,O_RDWR);
 	unlock_task(stream_lock,"s_connect_XLoHTTP");
