@@ -17,17 +17,11 @@
 
 
 
-#include	"lock_level.h"
 #include	"task.h"
 #include	"memory_debug.h"
 #include	"stream.h"
 #include	"s_buf.h"
 
-int s_chunk_read(STREAM * s,void * data,int len);
-
-#define COPY_IN_MAX_SIZE	4096
-
-
 
 int
 en_do(int * ret_len,int (*func)(),STREAM * s,void * data,int len)
@@ -82,7 +76,21 @@ SBUF_DATA * d;
 		unlock_task(lock,"free_sbuf");
 }
 
+int
+get_sbuf_data_size(STREAM_BUF * b,SEM lock)
+{
+SBUF_DATA * d;
+int ret;
 
+	if ( lock )
+		lock_task(lock);
+	ret = 0;
+	for ( d = b->head ; d ; d = d->next )
+		ret += d->len - d->ptr;
+	if ( lock )
+		unlock_task(lock,"get_sbuf_data_size");
+	return ret;
+}
 
 void
 copy_in_sbuf(STREAM_BUF * b,void * data,int len,SEM lock)
@@ -105,66 +113,6 @@ SBUF_DATA * d;
 		unlock_task(lock,"copy_in_sbuf");
 }
 
-int
-_copy_in_sbuf_stream(STREAM_BUF * b,STREAM * s,int len,SEM lock)
-{
-SBUF_DATA * d;
-int er;
-	d = d_alloc(sizeof(*d)+len);
-	er = en_do(&d->len,s_chunk_read,s,d+1,len);
-	if ( d->len == 0 ) {
-		d_f_ree(d);
-		return er;
-	}
-	d->next = 0;
-	d->ptr = 0;
-
-	if ( lock )
-		lock_task(lock);
-	if ( b->head ) {
-		b->tail->next = d;
-		b->tail = d;
-	}
-	else	b->head = b->tail = d;
-	if ( lock )
-		unlock_task(lock,"_copy_in_sbuf_stream");
-	if ( d->len > 0 )
-		return 1;
-	else 	return er;
-}
-
-int
-copy_in_sbuf_stream(STREAM_BUF * b,STREAM * s,int len,SEM lock)
-{
-int ret;
-	if ( len < 0 ) {
-		ret = 1;
-		for ( ; ret > 0 ; )
-			ret = _copy_in_sbuf_stream(
-					b,s,COPY_IN_MAX_SIZE,lock);
-		return ret;
-	}
-	else {
-		return _copy_in_sbuf_stream(b,s,len,lock);
-	}
-}
-
-int
-get_sbuf_data_size(STREAM_BUF * b,SEM lock)
-{
-SBUF_DATA * d;
-int ret;
-
-	if ( lock )
-		lock_task(lock);
-	ret = 0;
-	for ( d = b->head ; d ; d = d->next )
-		ret += d->len - d->ptr;
-	if ( lock )
-		unlock_task(lock,"get_sbuf_data_size");
-	return ret;
-}
-
 int
 copy_out_sbuf(STREAM_BUF * b,void * data,int size,SEM lock)
 {
