@@ -67,9 +67,9 @@ char ** d;
 	fprintf(stderr,"%s...\n",str);
 */
 	fflush(stderr);
-	d = d_alloc(TEST_LEN*sizeof(char*),13);
+	d = d_alloc(TEST_LEN*sizeof(char*));
 	for ( i = 0 ; i < TEST_LEN ; i ++ )
-		d[i] = d_alloc(i+1,14);
+		d[i] = d_alloc(i+1);
 	for ( i = 0 ; i < TEST_LEN ; i ++ )
 		d_f_ree(d[i]);
 	d_f_ree(d);
@@ -130,14 +130,30 @@ set_file_line(XL_FILE * f,int line)
 void
 gb_file_delete(XL_FILE * f)
 {
+void (*cf)(int,void*);
+void * work;
+	lock_task(lex_lock);
+	if ( f->flags & XLF_CLOSE ) {
+		unlock_task(lex_lock,"gb_file_delete(3)");
+		return;
+	}
+	f->flags |= XLF_CLOSE;
+	unlock_task(lex_lock,"gb_file_delete(3)");
+
 	if ( f->st && (f->flags & XLF_DONT_CLOSE) == 0 )
 		s_close(f->st);
 	f->st = 0;
-	if ( f->close_func )
-		(*f->close_func)(CF_CLOSE,f->close_work);
+
+	lock_task(lex_lock);
+	cf = f->close_func;
+	work = f->close_work;
 	f->close_func = 0;
 	f->close_work = 0;
-	f->flags |= XLF_CLOSE;
+	unlock_task(lex_lock,"gb_file_delete(2)");
+
+	if ( cf )
+		(*cf)(CF_CLOSE,work);
+
 	if ( f->cm ) {
 		(*f->cm->close)(0,f->cm_work);
 		f->cm = 0;
@@ -975,7 +991,7 @@ double fl_no;
 		f->yytextlen = len+1;
 	}
 	f->yytext[len] = 0;
-	buf = d_alloc((len+1)*sizeof(L_CHAR),15);
+	buf = d_alloc((len+1)*sizeof(L_CHAR));
 	for ( i = 0 ; i < len ; i ++ ) {
 		if ( f->yytext[i] &0xffffff00 )
 			buf[i] = 255;
@@ -1217,7 +1233,7 @@ number_hex:
 	}
 
 entity:
-	ent_name = d_alloc(sizeof(L_CHAR)*2,16);
+	ent_name = d_alloc(sizeof(L_CHAR)*2);
 	ptr = 1;
 	ent_name[0]= ch;
 	for ( ; ; ) {
