@@ -1111,12 +1111,19 @@ int ret;
 		unlock_parse("get_delay_info");
 		return CDT_NONDELAY;
 	}
-	if ( st )
-		*st = s->h.file->st;
+	if ( st ) {
+		if ( s->h.file )
+			*st = s->h.file->st;
+		else 	*st = 0;
+	}
 	if ( s->h.type != XLT_DELAY ) {
 		unlock_parse("get_delay_info");
 		return CDT_NONDELAY;
 	}
+	if ( s->h.file == 0 ) {
+		unlock_parse("get_delay_info");
+		return CDT_NONDELAY;
+	}
 	if ( s->h.file->flags & XLF_PARSE ) {
 		unlock_parse("get_delay_info");
 		return CDT_NONDELAY;
