@@ -18,6 +18,7 @@
 
 #include	"memory_debug.h"
 #include	"lock_level.h"
+#include	"pri_level.h"
 #include	"task.h"
 #include	"stream.h"
 #include	"s_buf.h"
@@ -27,17 +28,11 @@
 #define DEL_TIMEOUT1	600
 #define DEL_TIMEOUT2	6000
 #define XoH_HANGING_LIMIT	600
+#define EMPTY_TIMEOUT	2
 
 #define XoH_HASH_SIZE	13
 #define XoH_KEY(c)	(((c)[0]*3 + (c)[1])%XoH_HASH_SIZE)
 
-typedef struct XoH_list {
-	struct XoH_list *	next;
-	STREAM *		con;
-	XLoHTTP_HEADER		h;
-	HTTP_INFO		info;
-} XoH_LIST;
-
 typedef struct XoH_entry {
 	struct XoH_entry * 	next;
 	int			flags;
@@ -143,7 +138,9 @@ output_server_header(STREAM * s,HTTP_INFO * info)
 		s_printf(s,"Connection: keep-alive\r\n");
 	else	s_printf(s,"Connection: close\r\n");
 	s_printf(s,"Content-Type: application/xlohttp\r\n");
-	s_printf(s,"Content-Length: %i\r\n\r\n",info->content_length);
+	if ( info->content_length >= 0 )
+		s_printf(s,"Content-Length: %i\r\n",info->content_length);
+	s_printf(s,"\r\n");
 	return 0;
 }
 
@@ -157,6 +154,7 @@ HTTP_INFO info;
 	for ( ; lst ;  ) {
 		l = lst;
 		lst = lst->next;
+ss_printf("XoH FREE CONNECTION\n");
 		l->h.type = XoH_T_ERROR;
 		l->h.sum = 0;
 		change_endian_XLoHTTP_HEADER(&l->h);
@@ -221,10 +219,12 @@ XoH_LIST ** lp;
 		if ( (*lp)->h.seq - lst->h.seq > 0 ) {
 			lst->next = *lp;
 			*lp = lst;
+			e->last_polling = get_xltime();
 			wakeup_task((int)e);
 			return 0;
 		}
 	}
+
 	*lp = lst;
 	lst->next = 0;
 	e->last_polling = get_xltime();
@@ -331,6 +331,9 @@ HTTP_INFO o_info;
 		s_close(key->s);
 		return -1;
 	}
+/*
+ss_printf("HTTP %s %s\n",lst->info.method,lst->info.dir);
+*/
 	if ( lst->info.content_length >= 0 && 
 			lst->info.content_length < sizeof(lst->h) ) {
 		del_tick_with_data(timeout_stream,(int)lst->con);
@@ -339,6 +342,20 @@ HTTP_INFO o_info;
 		s_close(key->s);
 		return -1;
 	}
+	if ( strcmp(lst->info.method,"GET") == 0 ) {
+		del_tick_with_data(timeout_stream,(int)lst->con);
+		if ( strcmp(lst->info.dir,"/cgi-bin/download.cgi") == 0 ) {
+			free_HTTP_info(&lst->info);
+			d_f_ree(lst);
+			return new_accept_2(new_st,key);
+		}
+		else {
+			free_HTTP_info(&lst->info);
+			d_f_ree(lst);
+			s_close(key->s);
+			return -1;
+		}
+	}
 	if ( en_do(&ret_len,s_read,key->s,&lst->h,sizeof(lst->h)) <= 0 ) {
 		del_tick_with_data(timeout_stream,(int)lst->con);
 		free_HTTP_info(&lst->info);
@@ -350,13 +367,18 @@ HTTP_INFO o_info;
 
 	change_endian_XLoHTTP_HEADER(&lst->h);
 	lst->h.sum = XoH_checksum(&lst->h);
+	lst->tim = get_xltime();
 
 	lock_task(XoH_lock);
 	if ( lst->h.sum ) {
+ss_printf("CHECKSUM ERROR\n");
 		goto err;
 	}
 	else if ( lst->h.type == XoH_T_OPEN ) {
 	XLoHTTP_HEADER h;
+/*
+ss_printf("OPEN\n");
+*/
 		_new_cockie(lst->h.cockie);
 		e = _new_XoH_entry(lst->h.cockie);
 		s_open_fpipe(p);
@@ -367,15 +389,13 @@ HTTP_INFO o_info;
 		e->ip = key->ip;
 		e->xli = xli;
 
-
 		if ( lst->info.flags & XoHINF_F_KEEP_ALIVE )
 			e->flags |= XoH_E_KEEP_ALIVE;
 
-
 		ret = 1;
 
-		create_task(recv_task,(int)e,1);
-		create_task(send_task,(int)e,1);
+		create_task(recv_task,(int)e,PRI_WRITE_BUF);
+		create_task(send_task,(int)e,PRI_WRITE_BUF);
 
 		h = lst->h;
 
@@ -395,14 +415,45 @@ HTTP_INFO o_info;
 		en_do(&ret_len,s_write,lst->con,&h,sizeof(h));
 
 		if ( e->flags & XoH_E_KEEP_ALIVE )
-{
 			_insert_ss(lst->con,e->ip,e->xli,e->pl);
-}
 		else	s_close(lst->con);
 		free_HTTP_info(&lst->info);
 		d_f_ree(lst);
 	}
+	else if ( lst->h.type == XoH_T_TESTING_VER ) {
+	XLoHTTP_HEADER h;
+/*
+ss_printf("VER_2\n");
+*/
+		*new_st = 0;
+
+		ret = 0;
+
+		h.type = XoH_T_TESTING_VER;
+		h.seq = 2;
+		h.sum = 0;
+		change_endian_XLoHTTP_HEADER(&h);
+		h.sum = XoH_checksum(&h);
+
+		o_info.flags = 0;
+		o_info.content_length = sizeof(h);
+		output_server_header(lst->con,&o_info);
+		en_do(&ret_len,s_write,lst->con,&h,sizeof(h));
+
+		s_close(lst->con);
+		free_HTTP_info(&lst->info);
+		d_f_ree(lst);
+	}
+	else if ( lst->h.type == XoH_T_UPLOAD_SESSION ) {
+/*
+ss_printf("UPLOAD\n");
+*/
+		ret = new_upload_session(lst);
+	}
 	else {
+/*
+ss_printf("ELSE\n");
+*/
 		e = _search_XoH_entry(lst->h.cockie);
 		if ( e == 0 ) {
 		XLoHTTP_HEADER h;
@@ -411,6 +462,7 @@ HTTP_INFO o_info;
 			h = lst->h;
 			h.sum = 0;
 			h.type = XoH_T_ERROR;
+ss_printf("XoH INVALID COCKIE\n");
 			change_endian_XLoHTTP_HEADER(&h);
 			h.sum = XoH_checksum(&h);
 
@@ -507,7 +559,7 @@ XoH_LIST * lst;
 
 
 int
-_empty_reply(XoH_ENTRY * e)
+_empty_reply(XoH_ENTRY * e,unsigned int now)
 {
 XoH_LIST * lst;
 XLoHTTP_HEADER h;
@@ -522,8 +574,10 @@ int ret;
 	lst = e->list;
 	if ( lst->h.seq - e->recv_seq >= 0 )
 		goto end;
-
+	if ( now - lst->tim < EMPTY_TIMEOUT )
+		goto end;
 	e->list = lst->next;
+ss_printf("EMPTY REPLY %x - %i\n",e,lst->h.seq);
 
 	h = lst->h;
 	h.type = XoH_T_DATA;
@@ -788,7 +842,7 @@ unsigned int hl_last;
 		lock_task(XoH_lock);
 		for ( i = 0 ; i < XoH_HASH_SIZE ; i ++ )
 			for ( e = XoH_hash[i]; e ; e = e->next )
-				for ( ; _empty_reply(e) ; );
+				for ( ; _empty_reply(e,now) ; );
 		if ( now - hl_last >= 5 ) {
 			hl_last = get_xltime();
 			op = s_check_resource2(&opm);
