@@ -215,14 +215,14 @@ SERVER_INFO si;
 			xli->ip,xli->port,0,0);
 		break;
 	case PT_XLoHTTP:
-		xli->inp = s_connect_XLoHTTP(
+		xli->inp = s_connect_XLoHTTP_2(
 			cerr,
 			n_string(std_cm,xli->hostname),
 			xli->ip,xli->port,0,0,0,
 				http_proxy_keep_alive_mode);
 		break;
 	case PT_HTTP_PROXY:
-		xli->inp = s_connect_XLoHTTP(
+		xli->inp = s_connect_XLoHTTP_2(
 			cerr,
 			n_string(std_cm,xli->hostname),
 			xli->ip,xli->port,
